@@ -9,3 +9,7 @@
 # @Description  :
 
 
+from paddlespeech.cli.asr.infer import ASRExecutor
+
+asr = ASRExecutor()
+result = asr(audio_file="zh.wav")
